from setuptools import setup

setup(
    name='bb_krl Tank Battle',
    version='1.0.0',
    packages=['app'],
    url='https://github.com/bbkrl/TMS_homework',
    license='',
    author='bb_krl',
    author_email='bagushevich2003@mail.ru',
    description='package for consol tank battle'
)
